summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorallen <allen@17b73243-c579-4c4c-a9d2-2d5706c11dac>1999-02-13 15:44:22 +0000
committerallen <allen@17b73243-c579-4c4c-a9d2-2d5706c11dac>1999-02-13 15:44:22 +0000
commit25aa5df5e3622aa7f577e17635a1d6b6e5787169 (patch)
tree5c2b89bf99d382a350bfe92c93a3e959089d09d6 /lib
parent40f366d24b64855244cf8aea9d70ec3f60f2e1c9 (diff)
toolkit -> package
git-svn-id: http://svn.cactuscode.org/flesh/trunk@246 17b73243-c579-4c4c-a9d2-2d5706c11dac
Diffstat (limited to 'lib')
-rwxr-xr-xlib/make/configure4
-rw-r--r--lib/make/configure.in4
-rw-r--r--lib/make/make.config.defn.in2
-rw-r--r--lib/make/make.configuration12
-rwxr-xr-xlib/make/new_thorn.pl44
-rw-r--r--lib/sbin/BuildActiveThorns.pl20
-rw-r--r--lib/sbin/config_parser.pl14
-rw-r--r--lib/sbin/configure_thorns.pl2
8 files changed, 51 insertions, 51 deletions
diff --git a/lib/make/configure b/lib/make/configure
index 95616776..d0a58af5 100755
--- a/lib/make/configure
+++ b/lib/make/configure
@@ -1764,7 +1764,7 @@ F77FLAGS=$CFLAGS
-TOOLKIT_DIR=toolkits
+PACKAGE_DIR=packages
BUILD_DIR=build
CCTK_LIBDIR=lib
@@ -1946,7 +1946,7 @@ s%@LD@%$LD%g
s%@ARFLAGS@%$ARFLAGS%g
s%@F90FLAGS@%$F90FLAGS%g
s%@F77FLAGS@%$F77FLAGS%g
-s%@TOOLKIT_DIR@%$TOOLKIT_DIR%g
+s%@PACKAGE_DIR@%$PACKAGE_DIR%g
s%@BUILD_DIR@%$BUILD_DIR%g
s%@CCTK_LIBDIR@%$CCTK_LIBDIR%g
s%@EXE@%$EXE%g
diff --git a/lib/make/configure.in b/lib/make/configure.in
index c5bfe7e4..d1dc37ff 100644
--- a/lib/make/configure.in
+++ b/lib/make/configure.in
@@ -59,12 +59,12 @@ dnl Checks for library functions.
dnl Misc stuff
-AC_SUBST(TOOLKIT_DIR)
+AC_SUBST(PACKAGE_DIR)
AC_SUBST(BUILD_DIR)
AC_SUBST(CCTK_LIBDIR)
AC_SUBST(EXE)
-TOOLKIT_DIR=toolkits
+PACKAGE_DIR=packages
BUILD_DIR=build
CCTK_LIBDIR=lib
diff --git a/lib/make/make.config.defn.in b/lib/make/make.config.defn.in
index 5c412d4d..93ac120e 100644
--- a/lib/make/make.config.defn.in
+++ b/lib/make/make.config.defn.in
@@ -35,7 +35,7 @@ LDFLAGS = @LDFLAGS@
ARFLAGS = @ARFLAGS@
# Where the CCTK puts things
-TOOLKIT_DIR = $(CCTK_HOME)/@TOOLKIT_DIR@
+PACKAGE_DIR = $(CCTK_HOME)/@PACKAGE_DIR@
BUILD_DIR = $(TOP)/@BUILD_DIR@
CCTK_LIBDIR = $(TOP)/@CCTK_LIBDIR@
diff --git a/lib/make/make.configuration b/lib/make/make.configuration
index 96a806dd..b9431eeb 100644
--- a/lib/make/make.configuration
+++ b/lib/make/make.configuration
@@ -36,7 +36,7 @@ include $(CONFIG)/make.config.defn
# Allow each thorn to include some global definitions
ifneq ($(strip $(THORNS)),)
--include $(THORNS:%=$(TOOLKIT_DIR)/%/src/make.configuration.defn)
+-include $(THORNS:%=$(PACKAGE_DIR)/%/src/make.configuration.defn)
endif
# Build the executable
@@ -68,7 +68,7 @@ $(CCTK_LIBDIR)/lib%.a: update
thorn_name=$(@:$(CCTK_LIBDIR)/lib%.a=%); \
if [ "$$thorn_name" = "Cactus" ] ; then src_dir=$(CCTK_HOME)/src ; \
else if [ "$$thorn_name" = "CactusBindings" ] ; then src_dir=$(BINDINGS_DIR) ; \
- else src_dir=$(TOOLKIT_DIR)/$(@:$(CCTK_LIBDIR)/lib%.a=$(filter %/$(@:$(CCTK_LIBDIR)/lib%.a=%), $(THORNS)))/src ; fi ; fi ;\
+ else src_dir=$(PACKAGE_DIR)/$(@:$(CCTK_LIBDIR)/lib%.a=$(filter %/$(@:$(CCTK_LIBDIR)/lib%.a=%), $(THORNS)))/src ; fi ; fi ;\
if [ ! -d $(BUILD_DIR)/$$thorn_name ]; then $(MKDIR) $(BUILD_DIR)/$$thorn_name ; fi ; \
cd $(BUILD_DIR)/$$thorn_name ; \
if [ -r "$$src_dir/Makefile" ] ; then make_file=$$src_dir/Makefile ; \
@@ -83,7 +83,7 @@ include $(CONFIG)/make.config.deps
# Rule to build the make.thornlist file from the ActiveThorns file
-$(CONFIG)/make.thornlist: $(TOP)/ActiveThorns $(foreach lib, $(CCTK_HOME)/src $(THORNS:%=$(TOOLKIT_DIR)/%), $(lib)/param.ccl $(lib)/interface.ccl $(lib)/schedule.ccl)
+$(CONFIG)/make.thornlist: $(TOP)/ActiveThorns $(foreach lib, $(CCTK_HOME)/src $(THORNS:%=$(PACKAGE_DIR)/%), $(lib)/param.ccl $(lib)/interface.ccl $(lib)/schedule.ccl)
@echo $(DIVIDER)
if [ -r $@ ] ; then echo Reconfiguring thorns ; rm $@ ;\
else echo Configuring thorns ; fi
@@ -93,8 +93,8 @@ $(CONFIG)/make.thornlist: $(TOP)/ActiveThorns $(foreach lib, $(CCTK_HOME)/src $(
$(TOP)/ActiveThorns:
@echo $(DIVIDER)
- @echo Creating ActiveThorn list containing all thorns in the toolkits directory
- $(PERL) -s $(BUILD_ACTIVETHORNS) $(CCTK_HOME)/toolkits > $@
+ @echo Creating ActiveThorn list containing all thorns in the packages directory
+ $(PERL) -s $(BUILD_ACTIVETHORNS) $(CCTK_HOME)/packages > $@
action="yes"; if [ "x$$EDITOR" = "x" ] ; then EDITOR=vi ; fi; \
while [ "x$$action" = "xyes" -o "x$$action" = "xy" -o "x$$action" = "xYES" -o "x$$action" = "xY" ] ; \
do \
@@ -111,7 +111,7 @@ $(TOP)/ActiveThorns:
# Allow each thorn to include some global dependencies
ifneq ($(strip $(THORNS)),)
--include $(THORNS:%=$(TOOLKIT_DIR)/%/src/make.configuration.deps)
+-include $(THORNS:%=$(PACKAGE_DIR)/%/src/make.configuration.deps)
endif
# Phony targets.
diff --git a/lib/sbin/configure_thorns.pl b/lib/sbin/configure_thorns.pl
index b9797e1a..2fbb9a31 100644
--- a/lib/sbin/configure_thorns.pl
+++ b/lib/sbin/configure_thorns.pl
@@ -17,7 +17,7 @@ chdir $top;
chdir $config;
-chdir "toolkits";
+chdir "packages";
foreach $thorn (keys %activethorns)
{
diff --git a/lib/make/new_thorn.pl b/lib/make/new_thorn.pl
index a893387b..90f7a181 100755
--- a/lib/make/new_thorn.pl
+++ b/lib/make/new_thorn.pl
@@ -9,7 +9,7 @@
# @version $Id$
#@@*/
-$toolkit_dir = "toolkits";
+$package_dir = "packages";
$thorn_name = shift(@ARGV);
@@ -18,37 +18,37 @@ if(!$thorn_name)
$thorn_name = &prompt("Thorn name");
}
-if(!$toolkit)
+if(!$package)
{
- @toolkits = &GetToolkits($toolkit_dir);
+ @packages = &GetToolkits($package_dir);
- print "The following toolkits are available:\n";
- foreach $toolkit (@toolkits)
+ print "The following packages are available:\n";
+ foreach $package (@packages)
{
- print "$toolkit\n";
+ print "$package\n";
}
print "Pick one, or create a new one.\n";
- $toolkit = &prompt("Toolkit");
+ $package = &prompt("Toolkit");
}
-chdir $toolkit_dir;
+chdir $package_dir;
-if(! -d "$toolkit")
+if(! -d "$package")
{
- print "Creating new toolkit $toolkit\n";
+ print "Creating new package $package\n";
- mkdir($toolkit, 0755);
+ mkdir($package, 0755);
}
-chdir $toolkit;
+chdir $package;
if( -e $thorn_name)
{
die "Thorn $thorn_name already exists !";
}
-print "Creating thorn $thorn_name in $toolkit\n";
+print "Creating thorn $thorn_name in $package\n";
mkdir($thorn_name, 0755);
chdir $thorn_name;
@@ -182,7 +182,7 @@ sub prompt {
# @date Wed Feb 3 16:45:22 1999
# @author Tom Goodale
# @desc
# Gets a list of the current toolkits.
# @enddesc
# @calls
# @calledby
@@ -193,17 +193,17 @@ sub prompt {
sub GetToolkits
{
- local($toolkit_dir) = @_;
+ local($package_dir) = @_;
local($start_dir);
- local(@toolkits);
+ local(@packages);
$start_dir = `pwd`;
- chdir $toolkit_dir;
+ chdir $package_dir;
- open(TOOLKITS, "ls|");
+ open(PACKAGES, "ls|");
- while(<TOOLKITS>)
+ while(<PACKAGES>)
{
chop;
@@ -215,13 +215,13 @@ sub GetToolkits
# Just pick directories
if( -d $_)
{
- push (@toolkits, $_);
+ push (@packages, $_);
}
}
- close TOOLKITS;
+ close PACKAGES;
chdir $start_dir;
- return @toolkits;
+ return @packages;
}
@@ -182,7 +182,7 @@ sub prompt {
# @author Tom Goodale
# @desc
-# Gets a list of the current toolkits.
+# Gets a list of the current packages.
# @enddesc
# @calls
diff --git a/lib/sbin/BuildActiveThorns.pl b/lib/sbin/BuildActiveThorns.pl
index 47baef7b..3fb9c2f5 100644
--- a/lib/sbin/BuildActiveThorns.pl
+++ b/lib/sbin/BuildActiveThorns.pl
@@ -9,13 +9,13 @@
# @version $Id$
#@@*/
-$toolkit_dir = shift(@ARGV);
+$package_dir = shift(@ARGV);
-chdir $toolkit_dir;
+chdir $package_dir;
-open(TOOLKITS, "ls|");
+open(PACKAGES, "ls|");
-while(<TOOLKITS>)
+while(<PACKAGES>)
{
chop;
@@ -27,15 +27,15 @@ while(<TOOLKITS>)
# Just pick directories
if( -d $_)
{
- push (@toolkits, $_);
+ push (@packages, $_);
}
}
-close TOOLKITS;
+close PACKAGES;
-foreach $toolkit (@toolkits)
+foreach $package (@packages)
{
- chdir $toolkit;
+ chdir $package;
open(THORNLIST, "ls|");
@@ -48,13 +48,13 @@ foreach $toolkit (@toolkits)
next if (m:^\#:);
next if (m:~$:);
# Allow each toolkit to have a documentation directory.
next if (m:^doc$:);
# Just pick directories
if( -d $_)
{
- push(@total_thornlist, "$toolkit/$_");
+ push(@total_thornlist, "$package/$_");
}
}
chdir "..";
@@ -48,13 +48,13 @@ foreach $toolkit (@toolkits)
next if (m:^\#:);
next if (m:~$:);
- # Allow each toolkit to have a documentation directory.
+ # Allow each package to have a documentation directory.
next if (m:^doc$:);
# Just pick directories
diff --git a/lib/sbin/config_parser.pl b/lib/sbin/config_parser.pl
index 892a3fa0..c4a1aef5 100644
--- a/lib/sbin/config_parser.pl
+++ b/lib/sbin/config_parser.pl
@@ -127,7 +127,7 @@ sub CreateThornList
{
local($cctk_home, $activethorns) = @_;
local(%thornlist);
- local($thorn, $toolkit, $thorn_name);
+ local($thorn, $package, $thorn_name);
open(ACTIVE, "<$activethorns") || die "Cannot open ActiveThorns file $activethorns !";
@@ -151,14 +151,14 @@ sub CreateThornList
{
$thorn =~ m:(.*)[/\\](.*):;
- $toolkit = $1;
+ $package = $1;
$thorn_name = $2;
# No longer strip thorn_ off the beginning of a thorn name.
# $thorn_name =~ s/thorn_//;
- if( -r "$cctk_home/toolkits/$thorn/param.ccl" &&
- -r "$cctk_home/toolkits/$thorn/interface.ccl" &&
- -r "$cctk_home/toolkits/$thorn/schedule.ccl")
+ if( -r "$cctk_home/packages/$thorn/param.ccl" &&
+ -r "$cctk_home/packages/$thorn/interface.ccl" &&
+ -r "$cctk_home/packages/$thorn/schedule.ccl")
{
if( $thornlist{"$thorn_name"} )
{
@@ -166,7 +166,7 @@ sub CreateThornList
}
else
{
- $thornlist{"$thorn_name"} = "$cctk_home/toolkits/$thorn";
+ $thornlist{"$thorn_name"} = "$cctk_home/packages/$thorn";
}
}
else
@@ -246,7 +246,7 @@ sub CreateMakeThornlist
$thorns{$thorn} =~ m:(.*)/(.*)/(.*):;
# Onlu place toolkit_name/thorn_name in the file.
$thornlist .= " $2/$3";
}
@@ -246,7 +246,7 @@ sub CreateMakeThornlist
$thorns{$thorn} =~ m:(.*)/(.*)/(.*):;
- # Onlu place toolkit_name/thorn_name in the file.
+ # Onlu place package_name/thorn_name in the file.
$thornlist .= " $2/$3";
}